Tensor (dpnp.tensor)ΒΆ

dpnp.tensor provides a reference implementation of the Python Array API specification. The implementation uses data-parallel algorithms suitable for execution on accelerators, such as GPUs.

dpnp.tensor is written using C++ and SYCL and oneAPI extensions implemented in Intel(R) oneAPI DPC++ compiler.

This module contains: