Data type functionsΒΆ

The package dpnp.tensor contains the following data type functions conforming to Python Array API specification:

astype

Returns a copy of the dpnp.tensor.usm_ndarray, cast to a specified type.

can_cast

Determines if one data type can be cast to another data type according to Type Promotion Rules.

finfo

Returns machine limits for floating-point data types.

iinfo

Returns machine limits for integer data types.

isdtype

Returns a boolean indicating whether a provided dtype is of a specified data type kind.

result_type

Returns the dtype that results from applying the Type Promotion Rules to the arguments.