Indexing functionsΒΆ

These functions allow to retrieve or modify array elements indexed by either integral arrays of indices or boolean mask arrays.

extract

Returns the elements of an array that satisfies the condition.

place

Change elements of an array based on conditional and input values.

put

Puts values into an array along a given axis at given indices.

put_along_axis

Puts elements into an array at the one-dimensional indices specified by indices along a provided axis.

take

Takes elements from an array along a given axis at given indices.

take_along_axis

Returns elements from an array at the one-dimensional indices specified by indices along a provided axis.