Printing functionsΒΆ

Functions for controlling and customizing the string representation of arrays.

get_print_options

Returns a copy of current options for printing dpnp.tensor.usm_ndarray class.

set_print_options

Set options for printing dpnp.tensor.usm_ndarray class.

print_options

Context manager for print options.

usm_ndarray_repr

Returns a formatted string representing the elements of a dpnp.tensor.usm_ndarray and its data type, if not a default type.

usm_ndarray_str

Returns a string representing the elements of a dpnp.tensor.usm_ndarray.