Searching functionsΒΆ

argmax

Returns the indices of the maximum values of the input array x along a specified axis.

argmin

Returns the indices of the minimum values of the input array x along a specified axis.

count_nonzero

Counts the number of elements in the input array x which are non-zero.

nonzero

Return the indices of non-zero elements.

searchsorted

Finds the indices into x1 such that, if the corresponding elements in x2 were inserted before the indices, the order of x1, when sorted in ascending order, would be preserved.

where

Returns dpnp.tensor.usm_ndarray with elements chosen from x1 or x2 depending on condition.