Set FunctionsΒΆ

isin

Tests x in test_elements for each element of x.

unique_all

Returns the unique elements of an input array x, the first occurring indices for each unique element in x, the indices from the set of unique elements that reconstruct x, and the corresponding counts for each unique element in x.

unique_counts

Returns the unique elements of an input array x and the corresponding counts for each unique element in x.

unique_inverse

Returns the unique elements of an input array x and the indices from the set of unique elements that reconstruct x.

unique_values

Returns the unique elements of an input array x.