Sorting functionsΒΆ

argsort

Returns the indices that sort an array x along a specified axis.

sort

Returns a sorted copy of an input array x.

top_k

Returns the k largest or smallest values and their indices in the input array x along the specified axis axis.