Statistical FunctionsΒΆ

max

Calculates the maximum value of the input array x.

mean

Calculates the arithmetic mean of elements in the input array x.

min

Calculates the minimum value of the input array x.

prod

Calculates the product of elements in the input array x.

std

Calculates the standard deviation of elements in the input array x.

sum

Calculates the sum of elements in the input array x.

var

Calculates the variance of elements in the input array x.

logsumexp

Calculates the logarithm of the sum of exponentials of elements in the input array x.

reduce_hypot

Calculates the square root of the sum of squares of elements in the input array x.