USM array objectΒΆ

The array object represents a multi-dimensional tensor of uniform elemental datatype allocated on a Device. The tensor is stored in a USM allocation, which can be accessed via usm_ndarray.base attribute.

Implementation of usm_ndarray conforms to Array API standard specification.

usm_ndarray

An array object represents a multidimensional tensor of numeric elements stored in a USM allocation on a SYCL device.