Array creation functionsΒΆ
The following functions in dpnp.tensor can be used
to create new arrays:
Returns evenly spaced values within the half-open interval [start, stop) as a one-dimensional array. |
|
Converts input object to |
|
Creates |
|
Returns an uninitialized |
|
Creates |
|
Constructs |
|
Returns a new |
|
Returns a new |
|
Returns |
|
Creates tuple of |
|
Returns a new |
|
Returns a new |
|
Returns the lower triangular part of a matrix (or a stack of matrices) |
|
Returns the upper triangular part of a matrix (or a stack of matrices) |
|
Returns a new |
|
Creates |
|
Creates |
|
Creates a copy of given instance of |