Utility functions¶
Tests whether all input array elements evaluate to True along a given axis. |
|
Tests whether any input array elements evaluate to True along a given axis. |
|
Returns True if two arrays are element-wise equal within tolerances. |
|
Calculates the n-th discrete forward difference of x along axis. |
|
Copies content of |
|
Copies content of |
Device object¶
- class dpnp.tensor.Device(*args, **kwargs)[source]¶
An object representing Data-API concept of device.
This is a wrapper around
dpctl.SyclQueuewith custom formatting. The class does not have public constructor, but a class methoddpnp.tensor.Device.create_device()to construct it from device keyword argument in Array-API functions.Instance can be queried for
sycl_queue,sycl_context, orsycl_device.create_device([device])Creates instance of Device from argument.
sycl_queuedpctl.SyclQueueused to offload to thisDevice.sycl_devicedpctl.SyclDevicetargeted by thisDevice.sycl_contextdpctl.SyclContextassociated with thisDevice.print_device_info()Outputs information about targeted SYCL device
wait()Call
waitmethod of the underlyingsycl_queue.